@@ -1,7 +1,7 @@
 package App::DuckPAN;
 our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: The DuckDuckGo DuckPAN client
-$App::DuckPAN::VERSION = '0.190';
+$App::DuckPAN::VERSION = '0.191';
 use feature 'state';
 
 use Moo;
@@ -301,12 +301,12 @@ sub execute {
 				elsif($m eq 'ddg' && $ddg){ next }
 				push @modules, $_;
 			}
-			elsif (m/^duckpan|update|(upgrade|reinstall|latest)$/i) {
+			elsif (m/^duckpan|update|(upgrade|(reinstall|latest))$/i) {
 				my ($all_modules, $reinstall_latest) = map { lc } ($1, $2);
 				$self->empty_cache unless $self->empty;
 				push @modules, 'App::DuckPAN';
 				if($all_modules){
-					push @modules, 'DDG', map { "DDG::${_}Bundle::OpenSourceDuckDuckGo" } qw(Goodie Spice Fathead Longtail);
+					push @modules, 'DDG';
 					unshift @modules, $reinstall_latest if $reinstall_latest; 
 				}
 			}
@@ -403,31 +403,30 @@ sub phrase_to_camel {
 }
 
 sub check_requirements {
-	my ($self) = @_;
+        my ($self) = @_;
 
-	if (!$self->check) {
-		$self->emit_notice("Requirements checking was disabled...");
-		return 1;
-	}
-	my $signal_file = $self->cfg->cache_path->child('perl_checked');
-	my $last_checked_perl = ($signal_file->exists) ? $signal_file->stat->mtime : 0;
-	if ((time - $last_checked_perl) <= $self->cachesec) {
-		$self->emit_debug("Perl module versions recently checked, skipping requirements check...");
-	} else {
-		$self->emit_info("Checking for DuckPAN requirements...");
+        if (!$self->check) {
+                $self->emit_notice("Requirements checking was disabled...");
+                return 1;
+        }
+        my $signal_file = $self->cfg->cache_path->child('perl_checked');
+        my $last_checked_perl = ($signal_file->exists) ? $signal_file->stat->mtime : 0;
+        if ((time - $last_checked_perl) <= $self->cachesec) {
+                $self->emit_debug("Perl module versions recently checked, skipping requirements check...");
+        } else {
+                $self->emit_info("Checking for DuckPAN requirements...");
 
-		$self->emit_and_exit(1, 'Requirements check failed')
-		  unless (
-			$self->check_perl &&
-			$self->check_app_duckpan &&
-			$self->check_ddg &&
-			$self->check_ia_bundles &&
-			$self->check_ssh &&
-			$self->check_git);
-	}
-	$signal_file->touch;
+                $self->emit_and_exit(1, 'Requirements check failed')
+                  unless (
+                        $self->check_perl &&
+                        $self->check_app_duckpan &&
+                        $self->check_ddg &&
+                        $self->check_ssh &&
+                        $self->check_git);
+        }
+        $signal_file->touch;
 
-	return 1;
+        return 1;
 }
 
 sub get_local_ddg_version {
@@ -563,38 +562,6 @@ sub check_ddg {
 	return $ok;
 }
 
-sub check_ia_bundles {
-	my ($self)   = @_;
-	my $ok       = 1;
-	my @ia_types = qw(Goodie Spice Fathead Longtail);
-	my @bundles  = map { "DDG::${_}Bundle::OpenSourceDuckDuckGo" } @ia_types;
-
-	$self->emit_info("Checking for latest IA Bundles...");
-	my $packages = $self->duckpan_packages;
-	foreach my $bundle (@bundles){
-		my $installed_version = $self->perl->get_local_version($bundle);
-		my $module   = $packages->package($bundle);
-		my $latest   = $self->duckpan . 'authors/id/' . $module->distribution->pathname;
-		if ($installed_version && version->parse($installed_version) >= version->parse($module->version)) {
-			my $msg = "$bundle version: $installed_version";
-			$msg .= " (duckpan has " . $module->version . ")" if $installed_version ne $module->version;
-			$self->emit_debug($msg);
-		} else {
-			if ($installed_version) {
-				my @msg = (
-					"You have version $installed_version, latest is " . $module->version . "!",
-					"Please install the latest $bundle package with: duckpan $bundle"
-				);
-				$self->emit_notice(@msg);
-			} else {
-				$self->perl->duckpan_install($bundle);
-			}
-		}
-	}
-
-	return $ok;
-}
-
 sub checking_dukgo_user {
 	my ( $self, $user, $pass ) = @_;
 	my $request = GET( $self->dukgo_my_account );
@@ -647,7 +614,7 @@ App::DuckPAN - The DuckDuckGo DuckPAN client
 
 =head1 VERSION
 
-version 0.190
+version 0.191
 
 =head1 DuckPAN
 
