@@ -1,7 +1,7 @@
 package App::DuckPAN::Perl;
 our $AUTHORITY = 'cpan:DDG';
 # ABSTRACT: Perl related functionality for duckpan
-$App::DuckPAN::Perl::VERSION = '0.190';
+$App::DuckPAN::Perl::VERSION = '0.191';
 use Moo;
 with 'App::DuckPAN::HasApp';
 
@@ -129,8 +129,13 @@ sub duckpan_install {
 		if($reinstall || $latest || !$installed_version) {
 			# Prefer versions in the following order when (re)installing: installed, pinned, latest
 			# Latest ignores the installed version
-			my $version = $installed_version unless $latest;
+			my $version;
+			$version = $installed_version unless $latest;
 			$version ||= $pinned_version || $latest_version;
+			if($version == 9.999){
+				$self->app->emit_notice("You appear to be using a GitHub repository for unversioned package $package...skipping");
+				next;
+			}
 			# update the url if not the latest
 			if($version != $latest_version){
 				unless($duckpan_module_url = $self->find_previous_url($module, $version)){
@@ -234,7 +239,7 @@ App::DuckPAN::Perl - Perl related functionality for duckpan
 
 =head1 VERSION
 
-version 0.190
+version 0.191
 
 =head1 AUTHOR
 
